HolE
====

.. currentmodule:: pykeen.models

.. autoclass:: HolE
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~HolE.entity_constrainer_default_kwargs
      ~HolE.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~HolE.interaction_function
      ~HolE.score_h
      ~HolE.score_hrt
      ~HolE.score_t

   .. rubric:: Attributes Documentation

   .. autoattribute:: entity_constrainer_default_kwargs
   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: interaction_function
   .. automethod:: score_h
   .. automethod:: score_hrt
   .. automethod:: score_t
